package j2NLogDemo;

import com.jnbridge.jnbcore.DotNetSide;

import System.IDisposable;
import System.DotNetString;
import System.IO.FileInfo;
import System.Exception;

public class MainClass
{
	// Create a logger for use in this class
	private static log4net.ILog log = null;

	public static void main(String[] args)
	{
		DotNetSide.init(args[0]);

		log = log4net.LogManager.GetLogger("myLogger");

		log4net.Config.XmlConfigurator.Configure(new FileInfo(".\\J2NDemo.logging.config"));
		// Log an info level message
		if (log.Get_IsInfoEnabled()) 
		{
			log.Info(new DotNetString("Application [ConsoleApp] Start"));
		}

		// Log a debug message. Test if debug is enabled before
		// attempting to log the message. This is not required but
		// can make running without logging faster.
		if (log.Get_IsDebugEnabled()) log.Debug(new DotNetString("This is a debug message"));

		try
		{
			Bar();
		}
		catch(Exception ex)
		{
			// Log an error with an exception
			log.Error(new DotNetString("Exception thrown from method Bar"), ex);
		}

		log.Error(new DotNetString("Hey this is an error!"));

		// Push a message on to the Nested Diagnostic Context stack
		IDisposable id = log4net.NDC.Push("NDC_Message");
		log.Warn(new DotNetString("This should have an NDC message"));

		// Set a Mapped Diagnostic Context value  
		log4net.MDC.Set("auth", "auth-none");
		log.Warn(new DotNetString("This should have an MDC message for the key 'auth'"));

		id.Dispose();
		 // The NDC message is popped off the stack at the end of the using {} block

		log.Warn(new DotNetString("See the NDC has been popped of! The MDC 'auth' key is still with us."));

		// Log an info level message
		if (log.Get_IsInfoEnabled()) log.Info(new DotNetString("Application [ConsoleApp] End"));

		System.out.println("Done!");
	}

	private static void Bar()
	{
		Foo();
	}

	private static void Foo()
	{
		throw new Exception("This is an Exception");
	}

}

